@@ -16,10 +16,10 @@ int32_t SPVM__Net__SSLeay__ASN1_GENERALIZEDTIME__DESTROY(SPVM_ENV* env, SPVM_VAL
   
   void* obj_self = stack[0].oval;
   
-  ASN1_GENERALIZEDTIME* pointer = env->get_pointer(env, stack, obj_self);
+  ASN1_GENERALIZEDTIME* self = env->get_pointer(env, stack, obj_self);
   
   if (!env->no_free(env, stack, obj_self)) {
-    ASN1_GENERALIZEDTIME_free(pointer);
+    ASN1_GENERALIZEDTIME_free(self);
   }
   
   return 0;
