@@ -16,10 +16,10 @@ int32_t SPVM__Net__SSLeay__OCSP_SINGLERESP__DESTROY(SPVM_ENV* env, SPVM_VALUE* s
   
   void* obj_self = stack[0].oval;
   
-  OCSP_SINGLERESP* pointer = env->get_pointer(env, stack, obj_self);
+  OCSP_SINGLERESP* self = env->get_pointer(env, stack, obj_self);
   
   if (!env->no_free(env, stack, obj_self)) {
-    OCSP_SINGLERESP_free(pointer);
+    OCSP_SINGLERESP_free(self);
   }
   
   return 0;
