@@ -21,9 +21,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   SSL_METHOD* ssl_method = env->get_pointer(env, stack, obj_ssl_method);
   
-  SSL_CTX* ssl_ctx = SSL_CTX_new(ssl_method);
+  SSL_CTX* self = SSL_CTX_new(ssl_method);
   
-  if (!ssl_ctx) {
+  if (!self) {
     int64_t ssl_error = ERR_peek_last_error();
     
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
@@ -37,9 +37,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   // OpenSSL 1.1+ default
-  SSL_CTX_set_mode(ssl_ctx, SSL_MODE_AUTO_RETRY);
+  SSL_CTX_set_mode(self, SSL_MODE_AUTO_RETRY);
   
-  void* obj_self = env->new_pointer_object_by_name(env, stack, "Net::SSLeay::SSL_CTX", ssl_ctx, &error_id, __func__, FILE_NAME, __LINE__);
+  void* obj_self = env->new_pointer_object_by_name(env, stack, "Net::SSLeay::SSL_CTX", self, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_self;
@@ -61,9 +61,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_mode(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int64_t mode = stack[1].lval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t new_mode = SSL_CTX_set_mode(ssl_ctx, mode);
+  int64_t new_mode = SSL_CTX_set_mode(self, mode);
   
   stack[0].lval = new_mode;
   
@@ -78,9 +78,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_verify(SPVM_ENV* env, SPVM_VALUE* stack)
   
   int32_t mode = stack[1].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  SSL_CTX_set_verify(ssl_ctx, mode, NULL);
+  SSL_CTX_set_verify(self, mode, NULL);
   
   return 0;
 }
@@ -91,9 +91,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__get0_param(SPVM_ENV* env, SPVM_VALUE* stack)
   
   void* obj_self = stack[0].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  X509_VERIFY_PARAM* x509_verify_param = SSL_CTX_get0_param(ssl_ctx);
+  X509_VERIFY_PARAM* x509_verify_param = SSL_CTX_get0_param(self);
   
   void* obj_address_x509_verify_param = env->new_pointer_object_by_name(env, stack, "Address", x509_verify_param, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
@@ -115,9 +115,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_default_verify_paths(SPVM_ENV* env, SPVM
   
   void* obj_self = stack[0].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_set_default_verify_paths(ssl_ctx);
+  int32_t status = SSL_CTX_set_default_verify_paths(self);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -154,9 +154,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_certificate_file(SPVM_ENV* env, SPVM_VAL
   
   int32_t type = stack[2].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_use_certificate_file(ssl_ctx, file, type);
+  int32_t status = SSL_CTX_use_certificate_file(self, file, type);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -191,9 +191,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_certificate_chain_file(SPVM_ENV* env, SP
   char* file = (char*)env->get_chars(env, stack, obj_file);
   int32_t file_length = env->length(env, stack, obj_file);
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_use_certificate_chain_file(ssl_ctx, file);
+  int32_t status = SSL_CTX_use_certificate_chain_file(self, file);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -230,9 +230,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_PrivateKey_file(SPVM_ENV* env, SPVM_VALU
   
   int32_t type = stack[2].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_use_PrivateKey_file(ssl_ctx, file, type);
+  int32_t status = SSL_CTX_use_PrivateKey_file(self, file, type);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -269,9 +269,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_cipher_list(SPVM_ENV* env, SPVM_VALUE* s
   
   int32_t type = stack[2].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_set_cipher_list(ssl_ctx, str);
+  int32_t status = SSL_CTX_set_cipher_list(self, str);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -307,9 +307,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_ciphersuites(SPVM_ENV* env, SPVM_VALUE*
   
   int32_t type = stack[2].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_set_ciphersuites(ssl_ctx, str);
+  int32_t status = SSL_CTX_set_ciphersuites(self, str);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -334,7 +334,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__load_verify_locations(SPVM_ENV* env, SPVM_VA
   int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   void* obj_file = stack[1].oval;
   char* file = (char*)env->get_chars(env, stack, obj_file);
@@ -342,7 +342,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__load_verify_locations(SPVM_ENV* env, SPVM_VA
   void* obj_path = stack[2].oval;
   char* path = (char*)env->get_chars(env, stack, obj_path);
   
-  int32_t status = SSL_CTX_load_verify_locations(ssl_ctx, file, path);
+  int32_t status = SSL_CTX_load_verify_locations(self, file, path);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -368,9 +368,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__get_cert_store(SPVM_ENV* env, SPVM_VALUE* st
   
   void* obj_self = stack[0].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  X509_STORE* x509_store = SSL_CTX_get_cert_store(ssl_ctx);
+  X509_STORE* x509_store = SSL_CTX_get_cert_store(self);
   
   void* obj_address_x509_store = env->new_pointer_object_by_name(env, stack, "Address", x509_store, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
@@ -391,11 +391,11 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_options(SPVM_ENV* env, SPVM_VALUE* stack
   int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int64_t options = stack[1].lval;
   
-  int64_t ret = SSL_CTX_set_options(ssl_ctx, options);
+  int64_t ret = SSL_CTX_set_options(self, options);
   
   stack[0].lval = ret;
   
@@ -407,9 +407,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__get_options(SPVM_ENV* env, SPVM_VALUE* stack
   int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t ret = SSL_CTX_get_options(ssl_ctx);
+  int64_t ret = SSL_CTX_get_options(self);
   
   stack[0].lval = ret;
   
@@ -421,11 +421,11 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__clear_options(SPVM_ENV* env, SPVM_VALUE* sta
   int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int64_t options = stack[1].lval;
   
-  int64_t ret = SSL_CTX_clear_options(ssl_ctx, options);
+  int64_t ret = SSL_CTX_clear_options(self, options);
   
   stack[0].lval = ret;
   
@@ -452,9 +452,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_alpn_protos(SPVM_ENV* env, SPVM_VALUE* s
     protos_len = env->length(env, stack, obj_protos);
   }
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_set_alpn_protos(ssl_ctx, protos, protos_len);
+  int32_t status = SSL_CTX_set_alpn_protos(self, protos, protos_len);
   
   if (!(status == 0)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -488,9 +488,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tmp_ecdh(SPVM_ENV* env, SPVM_VALUE* stac
   
   EC_KEY* ecdh = env->get_pointer(env, stack, obj_ecdh);
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t status = SSL_CTX_set_tmp_ecdh(ssl_ctx, ecdh);
+  int64_t status = SSL_CTX_set_tmp_ecdh(self, ecdh);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -528,9 +528,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set1_groups_list(SPVM_ENV* env, SPVM_VALUE*
   
   const char* list = env->get_chars(env, stack, obj_list);
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t status = SSL_CTX_set1_groups_list(ssl_ctx, list);
+  int64_t status = SSL_CTX_set1_groups_list(self, list);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -565,9 +565,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set1_curves_list(SPVM_ENV* env, SPVM_VALUE*
   
   const char* list = env->get_chars(env, stack, obj_list);
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t status = SSL_CTX_set1_curves_list(ssl_ctx, list);
+  int64_t status = SSL_CTX_set1_curves_list(self, list);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -595,9 +595,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_session_cache_mode(SPVM_ENV* env, SPVM_V
   
   int64_t mode = stack[1].lval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t ret_mode = SSL_CTX_set_session_cache_mode(ssl_ctx, mode);
+  int64_t ret_mode = SSL_CTX_set_session_cache_mode(self, mode);
   
   stack[0].lval = ret_mode;
   
@@ -612,9 +612,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_ecdh_auto(SPVM_ENV* env, SPVM_VALUE* sta
   
   int32_t state = stack[1].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int64_t status = SSL_CTX_set_ecdh_auto(ssl_ctx, state);
+  int64_t status = SSL_CTX_set_ecdh_auto(self, state);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -642,7 +642,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tmp_dh(SPVM_ENV* env, SPVM_VALUE* stack)
   
   void* obj_dh = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_dh) {
     return env->die(env, stack, "The DH object $dh must be defined.", __func__, FILE_NAME, __LINE__);
@@ -650,7 +650,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tmp_dh(SPVM_ENV* env, SPVM_VALUE* stack)
   
   DH* dh = env->get_pointer(env, stack, obj_dh);
   
-  int64_t status = SSL_CTX_set_tmp_dh(ssl_ctx, dh);
+  int64_t status = SSL_CTX_set_tmp_dh(self, dh);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -678,9 +678,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_post_handshake_auth(SPVM_ENV* env, SPVM_
   
   int32_t val = stack[1].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  SSL_CTX_set_post_handshake_auth(ssl_ctx, val);
+  SSL_CTX_set_post_handshake_auth(self, val);
   
   return 0;
 }
@@ -693,7 +693,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_PrivateKey(SPVM_ENV* env, SPVM_VALUE* st
   
   void* obj_evp_pkey = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_evp_pkey) {
     return env->die(env, stack, "The EVP_PKEY object $pkey must be defined.", __func__, FILE_NAME, __LINE__);
@@ -701,7 +701,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_PrivateKey(SPVM_ENV* env, SPVM_VALUE* st
   
   EVP_PKEY* evp_pkey = env->get_pointer(env, stack, obj_evp_pkey);
   
-  int32_t status = SSL_CTX_use_PrivateKey(ssl_ctx, evp_pkey);
+  int32_t status = SSL_CTX_use_PrivateKey(self, evp_pkey);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -752,9 +752,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_session_id_context(SPVM_ENV* env, SPVM_V
     sid_ctx_len = env->length(env, stack, obj_sid_ctx);
   }
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_set_session_id_context(ssl_ctx, sid_ctx, sid_ctx_len);
+  int32_t status = SSL_CTX_set_session_id_context(self, sid_ctx, sid_ctx_len);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -782,9 +782,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_min_proto_version(SPVM_ENV* env, SPVM_VA
   
   int32_t version = stack[1].ival;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  int32_t status = SSL_CTX_set_min_proto_version(ssl_ctx, version);
+  int32_t status = SSL_CTX_set_min_proto_version(self, version);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -812,7 +812,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_client_CA_list(SPVM_ENV* env, SPVM_VALUE
   
   void* obj_list = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_list) {
     return env->die(env, stack, "The list $list must be defined.", __func__, FILE_NAME, __LINE__);
@@ -828,7 +828,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_client_CA_list(SPVM_ENV* env, SPVM_VALUE
     sk_X509_NAME_push(sk_x509_name, x509_name);
   }
   
-  SSL_CTX_set_client_CA_list(ssl_ctx, sk_x509_name);
+  SSL_CTX_set_client_CA_list(self, sk_x509_name);
   
   sk_X509_NAME_free(sk_x509_name);
   
@@ -843,7 +843,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__add_client_CA(SPVM_ENV* env, SPVM_VALUE* sta
   
   void* obj_x509 = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_x509) {
     return env->die(env, stack, "The X509 object $cacert must be defined.", __func__, FILE_NAME, __LINE__);
@@ -851,7 +851,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__add_client_CA(SPVM_ENV* env, SPVM_VALUE* sta
   
   X509* x509 = env->get_pointer(env, stack, obj_x509);
   
-  int32_t status = SSL_CTX_add_client_CA(ssl_ctx, x509);
+  int32_t status = SSL_CTX_add_client_CA(self, x509);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -879,7 +879,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__add_extra_chain_cert(SPVM_ENV* env, SPVM_VAL
   
   void* obj_x509 = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   if (!obj_x509) {
     return env->die(env, stack, "The X509 object $x509 must be defined.", __func__, FILE_NAME, __LINE__);
@@ -887,7 +887,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__add_extra_chain_cert(SPVM_ENV* env, SPVM_VAL
   
   X509* x509 = env->get_pointer(env, stack, obj_x509);
   
-  int32_t status = SSL_CTX_add_extra_chain_cert(ssl_ctx, x509);
+  int32_t status = SSL_CTX_add_extra_chain_cert(self, x509);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -983,7 +983,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tlsext_servername_callback(SPVM_ENV* env
   
   void* obj_arg = stack[2].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int (*native_cb)(SSL *s, int *al, void *arg) = NULL;
   
@@ -995,10 +995,10 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tlsext_servername_callback(SPVM_ENV* env
     native_args[1] = stack;
     native_args[2] = obj_cb;
     native_args[3] = obj_arg;
-    SSL_CTX_set_tlsext_servername_arg(ssl_ctx, native_args);
+    SSL_CTX_set_tlsext_servername_arg(self, native_args);
   }
   
-  int64_t status = SSL_CTX_set_tlsext_servername_callback(ssl_ctx, native_cb);
+  int64_t status = SSL_CTX_set_tlsext_servername_callback(self, native_cb);
   
   assert(status == 1);
   
@@ -1065,7 +1065,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tlsext_status_cb(SPVM_ENV* env, SPVM_VAL
   
   void* obj_arg = stack[2].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int (*native_cb)(SSL *s, void *arg) = NULL;
   
@@ -1077,10 +1077,10 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tlsext_status_cb(SPVM_ENV* env, SPVM_VAL
     native_args[1] = stack;
     native_args[2] = obj_cb;
     native_args[3] = obj_arg;
-    SSL_CTX_set_tlsext_status_arg(ssl_ctx, native_args);
+    SSL_CTX_set_tlsext_status_arg(self, native_args);
   }
   
-  int64_t status = SSL_CTX_set_tlsext_status_cb(ssl_ctx, native_cb);
+  int64_t status = SSL_CTX_set_tlsext_status_cb(self, native_cb);
   
   if (!(status == 1)) {
     int64_t ssl_error = ERR_peek_last_error();
@@ -1147,7 +1147,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_default_passwd_cb(SPVM_ENV* env, SPVM_VA
   
   void* obj_arg = stack[2].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   pem_password_cb* native_cb = NULL;
   
@@ -1159,10 +1159,10 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_default_passwd_cb(SPVM_ENV* env, SPVM_VA
     native_args[1] = stack;
     native_args[2] = obj_cb;
     native_args[3] = obj_arg;
-    SSL_CTX_set_default_passwd_cb_userdata(ssl_ctx, native_args);
+    SSL_CTX_set_default_passwd_cb_userdata(self, native_args);
   }
   
-  SSL_CTX_set_default_passwd_cb(ssl_ctx, native_cb);
+  SSL_CTX_set_default_passwd_cb(self, native_cb);
   
   return 0;
 }
@@ -1177,9 +1177,9 @@ static unsigned int SPVM__Net__SSLeay__SSL_CTX__my_psk_client_cb(SSL *ssl, const
   
   SPVM_VALUE* stack = env->new_stack(env);
   
-  SSL_CTX* ssl_ctx = SSL_get_SSL_CTX(ssl);
+  SSL_CTX* self = SSL_get_SSL_CTX(ssl);
   
-  if (!ssl_ctx) {
+  if (!self) {
     env->die(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
     
     print_exception_to_stderr(env, stack);
@@ -1188,7 +1188,7 @@ static unsigned int SPVM__Net__SSLeay__SSL_CTX__my_psk_client_cb(SSL *ssl, const
   }
   
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[0].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "GET_PSK_CLIENT_CB", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
@@ -1262,7 +1262,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_psk_client_callback(SPVM_ENV* env, SPVM_
   
   void* obj_cb = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   unsigned int (*native_cb)(SSL *ssl, const char *hint, char *identity, unsigned int max_identity_len, unsigned char *psk, unsigned int max_psk_len) = NULL;
   
@@ -1272,13 +1272,13 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_psk_client_callback(SPVM_ENV* env, SPVM_
   
   stack[0].oval = obj_self;
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   stack[2].oval = obj_cb;
   env->call_instance_method_by_name(env, stack, "SET_PSK_CLIENT_CB", 3, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  SSL_CTX_set_psk_client_callback(ssl_ctx, native_cb);
+  SSL_CTX_set_psk_client_callback(self, native_cb);
   
   return 0;
 }
@@ -1293,9 +1293,9 @@ static unsigned int SPVM__Net__SSLeay__SSL_CTX__my_psk_server_cb(SSL *ssl, const
   
   SPVM_VALUE* stack = env->new_stack(env);
   
-  SSL_CTX* ssl_ctx = SSL_get_SSL_CTX(ssl);
+  SSL_CTX* self = SSL_get_SSL_CTX(ssl);
   
-  if (!ssl_ctx) {
+  if (!self) {
     env->die(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
     
     print_exception_to_stderr(env, stack);
@@ -1304,7 +1304,7 @@ static unsigned int SPVM__Net__SSLeay__SSL_CTX__my_psk_server_cb(SSL *ssl, const
   }
   
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[0].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "GET_PSK_SERVER_CB", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
@@ -1367,7 +1367,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_psk_server_callback(SPVM_ENV* env, SPVM_
   
   void* obj_cb = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   SSL_psk_server_cb_func native_cb = NULL;
   
@@ -1377,13 +1377,13 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_psk_server_callback(SPVM_ENV* env, SPVM_
   
   stack[0].oval = obj_self;
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   stack[2].oval = obj_cb;
   env->call_instance_method_by_name(env, stack, "SET_TLSEXT_TICKET_KEY_CB", 3, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  SSL_CTX_set_psk_server_callback(ssl_ctx, native_cb);
+  SSL_CTX_set_psk_server_callback(self, native_cb);
   
   return 0;
 }
@@ -1398,9 +1398,9 @@ static unsigned int SPVM__Net__SSLeay__SSL_CTX__my_tlsext_ticket_key_cb(SSL *ssl
   
   SPVM_VALUE* stack = env->new_stack(env);
   
-  SSL_CTX* ssl_ctx = SSL_get_SSL_CTX(ssl);
+  SSL_CTX* self = SSL_get_SSL_CTX(ssl);
   
-  if (!ssl_ctx) {
+  if (!self) {
     env->die(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
     
     print_exception_to_stderr(env, stack);
@@ -1409,7 +1409,7 @@ static unsigned int SPVM__Net__SSLeay__SSL_CTX__my_tlsext_ticket_key_cb(SSL *ssl
   }
   
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[0].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "GET_TLSEXT_TICKET_KEY_CB", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
@@ -1516,7 +1516,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tlsext_ticket_key_cb(SPVM_ENV* env, SPVM
   
   void* obj_cb = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   unsigned int (*native_cb)(SSL *s, unsigned char* key_name, unsigned char* iv, EVP_CIPHER_CTX *ctx, HMAC_CTX *hctx, int enc) = NULL;
                  
@@ -1526,13 +1526,13 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_tlsext_ticket_key_cb(SPVM_ENV* env, SPVM
   
   stack[0].oval = obj_self;
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   stack[2].oval = obj_cb;
   env->call_instance_method_by_name(env, stack, "SET_TLSEXT_TICKET_KEY_CB", 3, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  SSL_CTX_set_tlsext_ticket_key_cb(ssl_ctx, native_cb);
+  SSL_CTX_set_tlsext_ticket_key_cb(self, native_cb);
   
   return 0;
 }
@@ -1586,7 +1586,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_alpn_select_cb_with_protocols(SPVM_ENV*
   
   void* obj_protocols = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int (*native_cb) (SSL *ssl, const unsigned char **out, unsigned char *outlen, const unsigned char *in, unsigned int inlen, void *arg) = NULL;
   
@@ -1599,7 +1599,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_alpn_select_cb_with_protocols(SPVM_ENV*
   native_args[1] = stack;
   native_args[2] = obj_protocols;
   
-  SSL_CTX_set_alpn_select_cb(ssl_ctx, native_cb, native_args);
+  SSL_CTX_set_alpn_select_cb(self, native_cb, native_args);
   
   return 0;
 }
@@ -1653,7 +1653,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_next_proto_select_cb_with_protocols(SPVM
   
   void* obj_protocols = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int (*native_cb) (SSL *ssl, unsigned char **out, unsigned char *outlen, const unsigned char *in, unsigned int inlen, void *arg) = NULL;
   
@@ -1666,7 +1666,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_next_proto_select_cb_with_protocols(SPVM
   native_args[1] = stack;
   native_args[2] = obj_protocols;
   
-  SSL_CTX_set_next_proto_select_cb(ssl_ctx, native_cb, native_args);
+  SSL_CTX_set_next_proto_select_cb(self, native_cb, native_args);
   
   return 0;
 }
@@ -1726,7 +1726,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_next_protos_advertised_cb_with_protocols
   
   void* obj_protocols = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int (*native_cb) (SSL *ssl, const unsigned char **out, unsigned int *outlen, void *arg) = NULL;
   
@@ -1743,7 +1743,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_next_protos_advertised_cb_with_protocols
   native_args[2] = obj_protocols;
   native_args[3] = obj_cb_output_strings_list;
   
-  SSL_CTX_set_next_protos_advertised_cb(ssl_ctx, native_cb, native_args);
+  SSL_CTX_set_next_protos_advertised_cb(self, native_cb, native_args);
   
   return 0;
 }
@@ -1758,9 +1758,9 @@ static int SPVM__Net__SSLeay__SSL_CTX__my_session_new_cb(SSL* ssl, SSL_SESSION*
   
   SPVM_VALUE* stack = env->new_stack(env);
   
-  SSL_CTX* ssl_ctx = SSL_get_SSL_CTX(ssl);
+  SSL_CTX* self = SSL_get_SSL_CTX(ssl);
   
-  if (!ssl_ctx) {
+  if (!self) {
     env->die(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
     
     print_exception_to_stderr(env, stack);
@@ -1769,7 +1769,7 @@ static int SPVM__Net__SSLeay__SSL_CTX__my_session_new_cb(SSL* ssl, SSL_SESSION*
   }
   
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[0].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "GET_NEW_SESSION_CB", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
@@ -1848,7 +1848,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__sess_set_new_cb(SPVM_ENV* env, SPVM_VALUE* s
   
   void* obj_cb = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   int (*native_cb)(SSL*, SSL_SESSION*) = NULL;
                  
@@ -1858,18 +1858,18 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__sess_set_new_cb(SPVM_ENV* env, SPVM_VALUE* s
   
   stack[0].oval = obj_self;
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   stack[2].oval = obj_cb;
   env->call_instance_method_by_name(env, stack, "SET_NEW_SESSION_CB", 3, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  SSL_CTX_sess_set_new_cb(ssl_ctx, native_cb);
+  SSL_CTX_sess_set_new_cb(self, native_cb);
   
   return 0;
 }
 
-static void SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb(SSL_CTX *ssl_ctx, SSL_SESSION* session) {
+static void SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb(SSL_CTX *self, SSL_SESSION* session) {
   
   int32_t error_id = 0;
   
@@ -1878,7 +1878,7 @@ static void SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb(SSL_CTX *ssl_ctx, S
   SPVM_VALUE* stack = env->new_stack(env);
   
   int32_t ret = 0;
-  if (!ssl_ctx) {
+  if (!self) {
     env->die(env, stack, "SSL_get_SSL_CTX(ssl) failed.", __func__, FILE_NAME, __LINE__);
     
     print_exception_to_stderr(env, stack);
@@ -1887,7 +1887,7 @@ static void SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb(SSL_CTX *ssl_ctx, S
   }
   
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[0].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "GET_REMOVE_SESSION_CB", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
@@ -1907,21 +1907,21 @@ static void SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb(SSL_CTX *ssl_ctx, S
     goto END_OF_FUNC;
   }
   
-  void* obj_address_ssl_ctx = env->new_pointer_object_by_name(env, stack, "Address", ssl_ctx, &error_id, __func__, FILE_NAME, __LINE__);
+  void* obj_address_self = env->new_pointer_object_by_name(env, stack, "Address", self, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
     print_exception_to_stderr(env, stack);
     
     goto END_OF_FUNC;
   }
-  stack[0].oval = obj_address_ssl_ctx;
+  stack[0].oval = obj_address_self;
   env->call_class_method_by_name(env, stack, "Net::SSLeay::SSL_CTX", "new_with_pointer", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
     print_exception_to_stderr(env, stack);
     
     goto END_OF_FUNC;
   }
-  void* obj_ssl_ctx = stack[0].oval;
-  env->set_no_free(env, stack, obj_ssl_ctx, 1);
+  void* obj_self = stack[0].oval;
+  env->set_no_free(env, stack, obj_self, 1);
   
   void* obj_address_session = env->new_pointer_object_by_name(env, stack, "Address", session, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
@@ -1940,7 +1940,7 @@ static void SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb(SSL_CTX *ssl_ctx, S
   env->set_no_free(env, stack, obj_session, 1);
   
   stack[0].oval = obj_cb;
-  stack[1].oval = obj_ssl_ctx;
+  stack[1].oval = obj_self;
   stack[2].oval = obj_session;
   
   env->call_instance_method_by_name(env, stack, "", 3, &error_id, __func__, FILE_NAME, __LINE__);
@@ -1965,9 +1965,9 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__sess_set_remove_cb(SPVM_ENV* env, SPVM_VALUE
   
   void* obj_cb = stack[1].oval;
   
-  SSL_CTX* ssl_ctx = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
-  void (*native_cb)(SSL_CTX *ssl_ctx, SSL_SESSION* session) = NULL;
+  void (*native_cb)(SSL_CTX *self, SSL_SESSION* session) = NULL;
   
   if (obj_cb) {
     native_cb = &SPVM__Net__SSLeay__SSL_CTX__my_session_remove_cb;
@@ -1975,13 +1975,13 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__sess_set_remove_cb(SPVM_ENV* env, SPVM_VALUE
   
   stack[0].oval = obj_self;
   char* tmp_buffer = env->get_stack_tmp_buffer(env, stack);
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", ssl_ctx);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   stack[2].oval = obj_cb;
   env->call_instance_method_by_name(env, stack, "SET_REMOVE_SESSION_CB", 3, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  SSL_CTX_sess_set_remove_cb(ssl_ctx, native_cb);
+  SSL_CTX_sess_set_remove_cb(self, native_cb);
   
   return 0;
 }
@@ -1994,40 +1994,40 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
-  SSL_CTX* pointer = env->get_pointer(env, stack, obj_self);
+  SSL_CTX* self = env->get_pointer(env, stack, obj_self);
   
   stack[0].oval = obj_self;
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", pointer);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "DELETE_PSK_CLIENT_CB", 2, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_self;
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", pointer);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "DELETE_PSK_SERVER_CB", 2, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_self;
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", pointer);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "DELETE_TLSEXT_TICKET_KEY_CB", 2, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_self;
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", pointer);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "DELETE_NEW_SESSION_CB", 2, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   stack[0].oval = obj_self;
-  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", pointer);
+  snprintf(tmp_buffer, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE, "%p", self);
   stack[1].oval = env->new_string(env, stack, tmp_buffer, strlen(tmp_buffer));
   env->call_instance_method_by_name(env, stack, "DELETE_REMOVE_SESSION_CB", 2, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
   if (!env->no_free(env, stack, obj_self)) {
-    SSL_CTX_free(pointer);
+    SSL_CTX_free(self);
   }
   
   return 0;
